import uuid

from fastapi import Response
from fastapi.datastructures import QueryParams
from sqlmodel import select

from openec2.config import OpenEC2Config
from openec2.db import DatabaseDep
from openec2.db.user import User
from openec2.db.instance import Instance
from openec2.api.describe_instance_types import DescribeInstanceTypesResponse, InstanceTypeInfo


def describe_instance_types(
    params: QueryParams,
    config: OpenEC2Config,
    db: DatabaseDep,
    user: User,
):
    response: list[InstanceTypeInfo] = []
    instances = db.exec(select(Instance).where(Instance.owner_id == user.id)).all()
    for instance in instances:
        response.append(
            InstanceTypeInfo(
                instanceType=instance.instanceType,
            ),
        )

    return Response(
        DescribeInstanceTypesResponse(
            requestId=uuid.uuid4().hex,
            instanceTypeSet=response,
            nextToken=None,
        ).to_xml(),
        media_type="application/xml",
    )
